# PaymentStatus

The status of the payment.

## Enum

* `DRAFT` (value: `'Draft'`)

* `PROCESSING` (value: `'Processing'`)

* `PROCESSED` (value: `'Processed'`)

* `ERROR` (value: `'Error'`)

* `CANCELED` (value: `'Canceled'`)

* `POSTED` (value: `'Posted'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


